@@ -55,6 +55,7 @@ MOVE_SETUP_CFG = 'move_setup_cfg'
 PIP_INSTALL_TEST_DEPS = 'pip_install_test_deps'
 PIP_INSTALL_TOX = 'pip_install_tox'
 PIP3_INSTALL_TOX = 'pip3_install_tox'
+EASY_INSTALL_TOX = 'easy_install_tox'
 PY3_ONLY = 'py3_only'
 PY3_TESTS_MUST_PASS = 'py3_tests_must_pass'
 RUN_SHELLCHECK = 'run_shellcheck'
@@ -215,12 +216,12 @@ def parse_vsc_ci_cfg():
         JIRA_ISSUE_ID_IN_PR_TITLE: False,
         MOVE_SETUP_CFG: False,
         PIP_INSTALL_TEST_DEPS: None,
-        PIP3_INSTALL_TOX: False,
+        EASY_INSTALL_TOX: False,
         RUN_SHELLCHECK: False,
         ENABLE_GITHUB_ACTIONS: False,
     }
 
-    deprecated_options = [PY3_ONLY, PY3_TESTS_MUST_PASS, PIP_INSTALL_TOX]
+    deprecated_options = [PY3_ONLY, PY3_TESTS_MUST_PASS, PIP_INSTALL_TOX, PIP3_INSTALL_TOX]
 
     if os.path.exists(VSC_CI_INI):
         try:
@@ -277,15 +278,15 @@ def gen_jenkinsfile():
 
     python_cmd = 'python3'
 
-    if vsc_ci_cfg[PIP3_INSTALL_TOX]:
-        pip_args += '--ignore-installed --prefix %s' % prefix
-        test_cmds.append('%s %s tox' % (install_cmd, pip_args))
-
-    else:
+    if vsc_ci_cfg[EASY_INSTALL_TOX]:
         install_cmd = install_cmd.replace('pip3 install', 'python -m easy_install')
         easy_install_args += '-U --user'
         test_cmds.append('%s %s tox' % (install_cmd, easy_install_args))
 
+    else:
+        pip_args += '--ignore-installed --prefix %s' % prefix
+        test_cmds.append('%s %s tox' % (install_cmd, pip_args))
+
     # Python version to use for updating $PYTHONPATH must be determined dynamically, so use $(...) trick;
     # we must stick to just double strings in the command used to determine the Python version, to avoid
     # that entire shell command is wrapped in triple quotes (which causes trouble)
